import slimPre
import numpy as np
R=6371e3 #radius of the earth

#get the boundary shapefile that you made in GIS
distCoast = slimPre.distance_shp("BndsV3_polyline.shp", 200, [1])

#get the bathyetry data
bath = slimPre.geo_tiff('../../Prepro/Data/layers/ausbath_09_v4.tif') #eAtlas

#get other data that will dictate mesh resolution
distMed = slimPre.distance_shp("../../Prepro/Data/layers/Original_Seagrass_Polygon.shp", 200)
disReef = slimPre.distance_shp("ReefDry_WGS84.shp", 200)

#set up attractor - will take the distance to the object and calculate the appropriate cell size
#object, distance min, distance max, length min, length max
def attractor (d, d0, d1, l0, l1):
    if d < d0 :
        s = l0
    elif d < d1 :
        f = (d-d0)/(d1-d0)
        s = l0*(1-f) + l1 * f
    else :
        s = l1
    return s


#use all the objects to calculate the cell sizes
def fsize(x, y, z) :
    d = distCoast.evaluate_geocentric(x,y,z)
    s1 = attractor(d,1500,100000,750,15000 )
    h = bath.evaluate_geocentric(x,y,z)
    s2 = attractor(np.sqrt(max(-h,0)),np.sqrt(10),np.sqrt(100),750,10000)
    m = np.minimum(distMed.evaluate_geocentric(x,y,z), disReef.evaluate_geocentric(x,y,z))
    s3 = attractor(m,2000,100000,1500,15000)
    return min(s1,s3)/R

#name the boundaries
physicals = {1:"coast", 2:"south_west", 3:"west", 4:"north_east", 5:"coral_sea", 6:"south_east"}
#construct the mesh
#inside the boundaries, lat, lon of a point inside the domain, size of the cells, ##, out_name, projection, names_of_boundaries
slimPre.mesh_shp(["BndsV3_polyline.shp"], 143.5, -10.5, fsize, 250/R, "torresV2.msh", "+proj=utm +zone=54 +south +ellps=WGS84", physicals)
