# -*- coding: utf-8 -*-
"""
Created on Fri May  1 13:25:48 2020

@author: schla

Generate a connectivity matrix of all 7000+ seed locations
for SLIM Torres Strait model.

"""

#%%
###Import packages
import numpy as np

#%%
###Parameters etc.

#Folder with run data.
years = '2011_2012'
Np = '2500'

#File path in
pathin = '/home/2/jc231398/TorresStrait/PostPro/SensitivityAnalysis/Phase2/'
#pathin = 'C:/Users/schla/Desktop/TorresStraitModelling/PostPro/SensitivityAnalysis/Analysis3-Distribution_SLIM/Phase2/ConnectivityMatrix/'
    
#%%
###Seed triangles
STriPath = pathin +'NodeElements.csv'
NodeElements = np.loadtxt(STriPath, delimiter = ",", skiprows =1)

SeedTris  = NodeElements[:,0].astype(int)
Groupings = NodeElements[:,3]

#For unique seed triangles. For matrix rows and columns.
UniSeedMesh = np.arange(0, SeedTris.shape[0], 1)

#Get unique groupings:
UniGroup = np.unique(Groupings)
    
#%%
###Import Con Mat R1
MatPath  = pathin +'R2/'+years +'/ConMatR1_' +Np +'.csv'
ConMatR1 = np.loadtxt(MatPath, delimiter = ',').T

#%%
###Generate and export Con Mat R2

#Generate empty connectivity matrix to fill according to groupings
ConMatR2 = np.zeros( (UniGroup.shape[0], UniGroup.shape[0]) )

#Loop unique groupings x 2

#From/source/rows
for i in range(UniGroup.shape[0]):
    #To/sink/cols
    for j in range(UniGroup.shape[0]):
        RowR1 = UniSeedMesh[ Groupings == UniGroup[i]]
        ColR1 = UniSeedMesh[ Groupings == UniGroup[j]]
        
        Rows = ConMatR1[RowR1, :]
        ConMatR2[i,j] = sum( sum(Rows[:,ColR1]))
        

#Save connectivity matrix
np.savetxt(pathin +'R2/' +years +'/ConMatR2_' +Np +'.csv', ConMatR2, delimiter = ',')
